extern crate downcast_rs;
extern crate ncurses;

use ncurses::*;

use std::thread::sleep;
use std::time;

mod lib {
    pub mod ai;
    pub mod entity;
    pub mod point;
    pub mod screen;
    pub mod world;
}

use lib::entity::{Ant, Entities, FoodGenerator};
use lib::point::Point;
use lib::screen::init_screen;
use lib::world::{render, simulate, World};

fn main() {
    let mut board = init_screen();
    let mut world = World::new(&Point(board.max_x, board.max_y));

    let mut entities = Entities::new();

    //let q = Queen::new(board.center.0,board.center.1);
    //entities.add_entity(&q);

    let fg = FoodGenerator::new();
    entities.add_entity(&fg);

    for _ in 0..5 {
        let mut a = Ant::new(board.center.0, board.center.1);
        a.goal = lib::ai::AIGoal::Seek;
        entities.add_entity(&a);
    }

    //world.create_chamber(Point(board.center.0, board.center.1), 3);

    let mut t = 0;
    loop {
        // TODO: add way to break out of the loop by hitting a random key
        simulate(&mut entities, &mut world, &mut board, t);
        render(&entities, &world, &board);
        sleep(time::Duration::from_millis(100));
        refresh();
        t += 1;
    }
    endwin();
}
